package com.sundot.airport.personnel.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sundot.airport.personnel.domain.PersonnelMonthlyAssessmentIndicatorDetail;

/**
 * 月度考核指标明细Service接口
 *
 * @author ruoyi
 * @date 2026-05-07
 */
public interface IPersonnelMonthlyAssessmentIndicatorDetailService extends IService<PersonnelMonthlyAssessmentIndicatorDetail> {
    /**
     * 查询月度考核指标明细
     *
     * @param id 月度考核指标明细主键
     * @return 月度考核指标明细
     */
    public PersonnelMonthlyAssessmentIndicatorDetail selectPersonnelMonthlyAssessmentIndicatorDetailById(Long id);

    /**
     * 查询月度考核指标明细列表
     *
     * @param personnelMonthlyAssessmentIndicatorDetail 月度考核指标明细
     * @return 月度考核指标明细集合
     */
    public List<PersonnelMonthlyAssessmentIndicatorDetail> selectPersonnelMonthlyAssessmentIndicatorDetailList(PersonnelMonthlyAssessmentIndicatorDetail personnelMonthlyAssessmentIndicatorDetail);

    /**
     * 新增月度考核指标明细
     *
     * @param personnelMonthlyAssessmentIndicatorDetail 月度考核指标明细
     * @return 结果
     */
    public int insertPersonnelMonthlyAssessmentIndicatorDetail(PersonnelMonthlyAssessmentIndicatorDetail personnelMonthlyAssessmentIndicatorDetail);

    /**
     * 修改月度考核指标明细
     *
     * @param personnelMonthlyAssessmentIndicatorDetail 月度考核指标明细
     * @return 结果
     */
    public int updatePersonnelMonthlyAssessmentIndicatorDetail(PersonnelMonthlyAssessmentIndicatorDetail personnelMonthlyAssessmentIndicatorDetail);

    /**
     * 批量删除月度考核指标明细
     *
     * @param ids 需要删除的月度考核指标明细主键集合
     * @return 结果
     */
    public int deletePersonnelMonthlyAssessmentIndicatorDetailByIds(Long[] ids);

    /**
     * 删除月度考核指标明细信息
     *
     * @param id 月度考核指标明细主键
     * @return 结果
     */
    public int deletePersonnelMonthlyAssessmentIndicatorDetailById(Long id);
}
